#!/bin/bash
#
# Component: log
#
# Description:
#    Collects study acquire log entries and prepares them for the accounting page
#
# Usage:
#     collectstudies.sh [-s startdate] [-e enddate] [-o outfile]
#
# start and end is either - (for today) or date day for older files
# start must be <= end
#
# Last Updated     : $Author: tnemeth $
# Update Date Time : $Date: 2014/04/29 14:40:51 $
# RCS File Name    : $RCSfile: collectstudies.sh,v $
# RCS Revision     : $Revision: 1.13 $
# Locked by        : $Locker:  $
# Symbolic name    : $Name:  $
# State            : $State: Exp $
#

usage()
{
	cat <<-END_OF_USAGE >&2
		usage: collectstudies.sh [-n] [-s start] [-e end] [-o outfile]
		    -s start                 : start date, '-' means today (default : '-')
		    -e end                   : end date,   '-' means today (default : '-')
		    -o outfile               : write the result to this file instead of stdout
		    -n                       : if specified, derived (merged, split) studies will not be listed
		    -t                       : if specified, prints total only
		END_OF_USAGE
	exit
} # usage

. $HOME/etc/setenv.sh

start=""
end=""
outfile=""
sumfile=""
totalOnly=""
hideDerived="false"

while getopts 's:e:o:hnt' OPT; do
	case $OPT in
		s) start="$OPTARG" ;;
		e) end="$OPTARG" ;;
		o) outfile="$OPTARG" ;;
		n) hideDerived="true" ;;
		t) totalOnly="true" ;;
		h) usage ;;
		*) usage ;;
	esac
done

[ -z "$start" ] && start="-"
[ -z "$end" ] && end="-"


tmpoutfile="/dev/stdout"
tmpsumfile="/dev/stdout"

if [ -n "$outfile" ] ; then
	tmpoutfile="$outfile.$$"
	tmpsumfile="$outfile.sum.$$"
fi


$LOG_HOME/viewlog.sh -s $start -e $end -a acquire,mergestudy,split | \
$LOG_HOME/collectstudies.awk -vHideDerived="$hideDerived" -vTotalOnly="$totalOnly" -vOut="$tmpoutfile" -vSum="$tmpsumfile" -vIgn="$BILLING_VAR/ignorestudies"

# move temporary file to its final place
if [ -n "$outfile" ] ; then
	mv "$tmpoutfile" "$outfile"
	mv "$tmpsumfile" "$outfile.sum"
fi

